@@ -8,8 +8,12 @@ setMethod("mean", "DVH.list",
 		dose <- match.arg(dose)
 		dose.units <- match.arg(dose.units)
 		volume <- match.arg(volume)
-		x <- new("DVH.list", lapply(x, convert.DVH, type=type, dose=dose, dose.units=dose.units, volume=volume))
+		x <- x[!unlist(lapply(x, is.empty))]
 		N <- length(x)
+		if (N < 1) {
+			return(x)
+		}
+		x <- new("DVH.list", lapply(x, convert.DVH, type=type, dose=dose, dose.units=dose.units, volume=volume))
 		structure.name <- paste("mean(", paste(names(x), collapse=", ", sep=""), ")", sep="")
 		structure.volumes <- as.numeric(lapply(x, slot, "structure.volume"))
 		structure.means <- as.numeric(lapply(x, slot, "dose.mean"))
@@ -66,21 +70,38 @@ setGeneric("median",
 
 setMethod("median", "DVH.list",
 	function (x, na.rm=TRUE) {
+		x <- x[!unlist(lapply(x, is.empty))]
 		N <- length(x)
 		if (N < 1) {
-			stop("argument 'x' is missing with no default")
+			return(x)
 		}
-		if (length(unique(unlist(lapply(x, slot, "type")))) > 1) {
-			stop("'type' parameter must be the same for all DVH data (e.g. cumulative or differential)")
+		identical.format <- TRUE
+		type.format <- unique(unlist(lapply(x, slot, "type")))
+		if (length(type.format) > 1) {
+			warning("DVH 'type' parameter differs among DVH data (will reinterpet all data as cumulative DVH)")
+			type.format <- "cumulative"
+			identical.format <- FALSE
 		}
-		if (length(unique(unlist(lapply(x, slot, "dose.type")))) > 1) {
-			stop("'dose.type' parameter must be the same for all DVH data (e.g. absolute or relative)")
+		dose.format <- unique(unlist(lapply(x, slot, "dose.type")))
+		if (length(dose.format) > 1) {
+			warning("'dose.type' parameter differs among DVH data (will reinterpret all data relative dose)")
+			dose.format <- "relative"
+			identical.format <- FALSE
 		}
-		if (length(unique(unlist(lapply(x, slot, "volume.type")))) > 1) {
-			stop("'volume.type' parameter must be the same for all DVH data (e.g. absolute or relative)")
+		volume.format <- unique(unlist(lapply(x, slot, "volume.type")))
+		if (length(volume.format) > 1) {
+			warning("'volume.type' parameter differs among DVH data (will reinterpret all data as relative volume)")
+			volume.format <- "relative"
+			identical.format <- FALSE
 		}
-		if (length(unique(unlist(lapply(x, slot, "dose.units")))) > 1) {
-			stop("'dose.units' parameter must be the same for all DVH data (e.g. cGy or Gy)")
+		units.format <- unique(unlist(lapply(x, slot, "dose.units")))
+		if (length(units.format) > 1) {
+			warning("'dose.units' parameter differs among DVH data (will reinterpret all doses as cGy)")
+			units.format <- "cGy"
+			identical.format <- FALSE
+		}
+		if (!identical.format) {
+			x <- convert.DVH(x, type=type.format, dose=dose.format, volume=volume.format, dose.units=units.format)
 		}
 		structure.name <- paste("median(", paste(names(x), collapse=", ", sep=""), ")", sep="")
 		structure.volume <- median(as.numeric(lapply(x, slot, "structure.volume")), na.rm=na.rm)
@@ -109,21 +130,38 @@ setGeneric("mad",
 
 setMethod("mad", "DVH.list",
 	function (x) {
+		x <- x[!unlist(lapply(x, is.empty))]
 		N <- length(x)
 		if (N < 1) {
-			return(NA)
+			return()
 		}
-		if (length(unique(unlist(lapply(x, slot, "type")))) > 1) {
-			stop("'type' parameter must be the same for all DVH data (e.g. cumulative or differential)")
+		identical.format <- TRUE
+		type.format <- unique(unlist(lapply(x, slot, "type")))
+		if (length(type.format) > 1) {
+			warning("DVH 'type' parameter differs among DVH data (will reinterpet all data as cumulative DVH)")
+			type.format <- "cumulative"
+			identical.format <- FALSE
 		}
-		if (length(unique(unlist(lapply(x, slot, "dose.type")))) > 1) {
-			stop("'dose.type' parameter must be the same for all DVH data (e.g. absolute or relative)")
+		dose.format <- unique(unlist(lapply(x, slot, "dose.type")))
+		if (length(dose.format) > 1) {
+			warning("'dose.type' parameter differs among DVH data (will reinterpret all data relative dose)")
+			dose.format <- "relative"
+			identical.format <- FALSE
 		}
-		if (length(unique(unlist(lapply(x, slot, "volume.type")))) > 1) {
-			stop("'volume.type' parameter must be the same for all DVH data (e.g. absolute or relative)")
+		volume.format <- unique(unlist(lapply(x, slot, "volume.type")))
+		if (length(volume.format) > 1) {
+			warning("'volume.type' parameter differs among DVH data (will reinterpret all data as relative volume)")
+			volume.format <- "relative"
+			identical.format <- FALSE
 		}
-		if (length(unique(unlist(lapply(x, slot, "dose.units")))) > 1) {
-			stop("'dose.units' parameter must be the same for all DVH data (e.g. cGy or Gy)")
+		units.format <- unique(unlist(lapply(x, slot, "dose.units")))
+		if (length(units.format) > 1) {
+			warning("'dose.units' parameter differs among DVH data (will reinterpret all doses as cGy)")
+			units.format <- "cGy"
+			identical.format <- FALSE
+		}
+		if (!identical.format) {
+			x <- convert.DVH(x, type=type.format, dose=dose.format, volume=volume.format, dose.units=units.format)
 		}
 		size <- ceiling(mean(as.numeric(lapply(x, function(DVH) { length(DVH@doses) })), na.rm=TRUE))
 		dose.min <- min(x)
@@ -147,21 +185,38 @@ setGeneric("quantile",
 
 setMethod("quantile", "DVH.list",
 	function (x, type=7, ...) {
+		x <- x[!unlist(lapply(x, is.empty))]
 		N <- length(x)
 		if (N < 1) {
-			return(NA)
+			return()
 		}
-		if (length(unique(unlist(lapply(x, slot, "type")))) > 1) {
-			stop("'type' parameter must be the same for all DVH data (e.g. cumulative or differential)")
+		identical.format <- TRUE
+		type.format <- unique(unlist(lapply(x, slot, "type")))
+		if (length(type.format) > 1) {
+			warning("DVH 'type' parameter differs among DVH data (will reinterpet all data as cumulative DVH)")
+			type.format <- "cumulative"
+			identical.format <- FALSE
 		}
-		if (length(unique(unlist(lapply(x, slot, "dose.type")))) > 1) {
-			stop("'dose.type' parameter must be the same for all DVH data (e.g. absolute or relative)")
+		dose.format <- unique(unlist(lapply(x, slot, "dose.type")))
+		if (length(dose.format) > 1) {
+			warning("'dose.type' parameter differs among DVH data (will reinterpret all data relative dose)")
+			dose.format <- "relative"
+			identical.format <- FALSE
 		}
-		if (length(unique(unlist(lapply(x, slot, "volume.type")))) > 1) {
-			stop("'volume.type' parameter must be the same for all DVH data (e.g. absolute or relative)")
+		volume.format <- unique(unlist(lapply(x, slot, "volume.type")))
+		if (length(volume.format) > 1) {
+			warning("'volume.type' parameter differs among DVH data (will reinterpret all data as relative volume)")
+			volume.format <- "relative"
+			identical.format <- FALSE
 		}
-		if (length(unique(unlist(lapply(x, slot, "dose.units")))) > 1) {
-			stop("'dose.units' parameter must be the same for all DVH data (e.g. cGy or Gy)")
+		units.format <- unique(unlist(lapply(x, slot, "dose.units")))
+		if (length(units.format) > 1) {
+			warning("'dose.units' parameter differs among DVH data (will reinterpret all doses as cGy)")
+			units.format <- "cGy"
+			identical.format <- FALSE
+		}
+		if (!identical.format) {
+			x <- convert.DVH(x, type=type.format, dose=dose.format, volume=volume.format, dose.units=units.format)
 		}
 		size <- ceiling(mean(as.numeric(lapply(x, function(DVH) { length(DVH@doses) })), na.rm=TRUE))
 		dose.min <- min(x)
@@ -181,21 +236,38 @@ setGeneric("var",
 
 setMethod("var", "DVH.list",
 	function (x, na.rm=TRUE) {
+		x <- x[!unlist(lapply(x, is.empty))]
 		N <- length(x)
 		if (N < 1) {
-			return(NA)
+			return()
 		}
-		if (length(unique(unlist(lapply(x, slot, "type")))) > 1) {
-			stop("'type' parameter must be the same for all DVH data (e.g. cumulative or differential)")
+		identical.format <- TRUE
+		type.format <- unique(unlist(lapply(x, slot, "type")))
+		if (length(type.format) > 1) {
+			warning("DVH 'type' parameter differs among DVH data (will reinterpet all data as cumulative DVH)")
+			type.format <- "cumulative"
+			identical.format <- FALSE
 		}
-		if (length(unique(unlist(lapply(x, slot, "dose.type")))) > 1) {
-			stop("'dose.type' parameter must be the same for all DVH data (e.g. absolute or relative)")
+		dose.format <- unique(unlist(lapply(x, slot, "dose.type")))
+		if (length(dose.format) > 1) {
+			warning("'dose.type' parameter differs among DVH data (will reinterpret all data relative dose)")
+			dose.format <- "relative"
+			identical.format <- FALSE
 		}
-		if (length(unique(unlist(lapply(x, slot, "volume.type")))) > 1) {
-			stop("'volume.type' parameter must be the same for all DVH data (e.g. absolute or relative)")
+		volume.format <- unique(unlist(lapply(x, slot, "volume.type")))
+		if (length(volume.format) > 1) {
+			warning("'volume.type' parameter differs among DVH data (will reinterpret all data as relative volume)")
+			volume.format <- "relative"
+			identical.format <- FALSE
 		}
-		if (length(unique(unlist(lapply(x, slot, "dose.units")))) > 1) {
-			stop("'dose.units' parameter must be the same for all DVH data (e.g. cGy or Gy)")
+		units.format <- unique(unlist(lapply(x, slot, "dose.units")))
+		if (length(units.format) > 1) {
+			warning("'dose.units' parameter differs among DVH data (will reinterpret all doses as cGy)")
+			units.format <- "cGy"
+			identical.format <- FALSE
+		}
+		if (!identical.format) {
+			x <- convert.DVH(x, type=type.format, dose=dose.format, volume=volume.format, dose.units=units.format)
 		}
 		size <- ceiling(mean(as.numeric(lapply(x, function(DVH) { length(DVH@doses) })), na.rm=TRUE))
 		dose.min <- min(x)
@@ -206,7 +278,7 @@ setMethod("var", "DVH.list",
 		}
 		volume.matrix <- matrix(NA, ncol=N, nrow=size)
 		for (i in 1:N) {
-			volume.matrix[,i] <- approx(x[[i]]$doses, x[[i]]$volumes, doses.new, rule=2)$y
+			volume.matrix[,i] <- pmax(0, approx(x[[i]]$doses, x[[i]]$volumes, doses.new, rule=2)$y, na.rm=TRUE)
 		}
 		return(list(dose=doses.new, var=apply(volume.matrix, 1, var, na.rm=na.rm)))
 	}
@@ -218,21 +290,38 @@ setGeneric("sd",
 
 setMethod("sd", "DVH.list",
 	function (x, na.rm=TRUE) {
+		x <- x[!unlist(lapply(x, is.empty))]
 		N <- length(x)
 		if (N < 1) {
-			return(NA)
+			return()
 		}
-		if (length(unique(unlist(lapply(x, slot, "type")))) > 1) {
-			stop("'type' parameter must be the same for all DVH data (e.g. cumulative or differential)")
+		identical.format <- TRUE
+		type.format <- unique(unlist(lapply(x, slot, "type")))
+		if (length(type.format) > 1) {
+			warning("DVH 'type' parameter differs among DVH data (will reinterpet all data as cumulative DVH)")
+			type.format <- "cumulative"
+			identical.format <- FALSE
 		}
-		if (length(unique(unlist(lapply(x, slot, "dose.type")))) > 1) {
-			stop("'dose.type' parameter must be the same for all DVH data (e.g. absolute or relative)")
+		dose.format <- unique(unlist(lapply(x, slot, "dose.type")))
+		if (length(dose.format) > 1) {
+			warning("'dose.type' parameter differs among DVH data (will reinterpret all data relative dose)")
+			dose.format <- "relative"
+			identical.format <- FALSE
 		}
-		if (length(unique(unlist(lapply(x, slot, "volume.type")))) > 1) {
-			stop("'volume.type' parameter must be the same for all DVH data (e.g. absolute or relative)")
+		volume.format <- unique(unlist(lapply(x, slot, "volume.type")))
+		if (length(volume.format) > 1) {
+			warning("'volume.type' parameter differs among DVH data (will reinterpret all data as relative volume)")
+			volume.format <- "relative"
+			identical.format <- FALSE
 		}
-		if (length(unique(unlist(lapply(x, slot, "dose.units")))) > 1) {
-			stop("'dose.units' parameter must be the same for all DVH data (e.g. cGy or Gy)")
+		units.format <- unique(unlist(lapply(x, slot, "dose.units")))
+		if (length(units.format) > 1) {
+			warning("'dose.units' parameter differs among DVH data (will reinterpret all doses as cGy)")
+			units.format <- "cGy"
+			identical.format <- FALSE
+		}
+		if (!identical.format) {
+			x <- convert.DVH(x, type=type.format, dose=dose.format, volume=volume.format, dose.units=units.format)
 		}
 		size <- ceiling(mean(as.numeric(lapply(x, function(DVH) { length(DVH@doses) })), na.rm=TRUE))
 		dose.min <- min(x)
@@ -326,9 +415,9 @@ setMethod("range", "DVH",
 setMethod("sum", "DVH.list",
 	function (x, ..., type=c("cumulative", "differential"), dose=c("absolute", "relative"), dose.units=c("cGy", "Gy"), volume=c("relative", "absolute"), na.rm = TRUE) {
 		x <- c(x, ...)
+		x <- x[!unlist(lapply(x, is.empty))]
 		N <- length(x)
-		if (N < 2) {
-			warning("DVH list must contain at least 2 DVH objects in order to generate a sum")
+		if (N <= 1) {
 			return(x)
 		}
 		type <- match.arg(type)
